Glossary
--------

.. glossary::

    Aliasing
      A circumstance where two or more variables refer to the same object.

    Delimiter
      A character or string used to indicate where a string should be split.

    Element
      One of the values in a list (or other sequence); also called items.

    Equivalent
      Having the same value.

    Index
      An integer value that indicates an element in a list.

    Identical
      Being the same object (which implies equivalence).

    List
      A sequence of values.

    List Traversal
      The sequential accessing of each element in a list.

    Nested List
      A list that is an element of another list

    Object
      Something a variable can refer to. An object has a type and a value.

    Reference
      The association between a variable and its value.


.. dragndrop:: list_glossary1
    :practice: T
    :feedback: Look above for the definitions of these terms.
    :match_1: Aliasing|||A circumstance where two or more variables refer to the same object.
    :match_2: Element|||One of the values in a list (or other sequence).
    :match_3: Equivalent||| Having the same value.
    :match_4: Identical|||Being the same object (which implies equivalence).
    :match_5: Object||| Something a variable can refer to.
    :match_6: Reference||| The association between a variable and its value.

    Match each term to its definition.

.. dragndrop:: list_glossary2
    :practice: T
    :feedback: Look above for the definitions of these terms.
    :match_1: Delimiter|||A character or string used to indicate where a string should be split.
    :match_2: Index|||An integer value that indicates an element in a list.
    :match_3: List|||A sequence of values.
    :match_4: List Traversal||| The sequential accessing of each element in a list.
    :match_5: Nested List|||A list that is an element of another list.
